@@ -2,11 +2,9 @@ import logging
 import os
 import re
 
-from lxml.etree import XMLSyntaxError
-
 from errors import *
-from lib.thetvdb import TheTvDb as thetvdb
-from lib.tvrage import TvRage as tvrage
+from lib.thetvdb import TheTvDb
+from lib.tvrage import TvRage
 
 log = logging.getLogger('Core')
 
@@ -96,16 +94,11 @@ class TvRenamr():
         :rtype: A string.
         """
         libraries = [
-            ('thetvdb', thetvdb),
-            ('tvrage', tvrage),
+            TheTvDb,
+            TvRage
         ]
-        choice = None
-        for i, lib in enumerate(libraries):
-            if lib[0] == library:
-                choice = lib
-                libraries.pop(i)
-                break
-        libraries.insert(0, choice)
+        [libraries.insert(0, libraries.pop(libraries.index(lib)))
+        for lib in libraries if lib.__name__.lower() == library]
 
         if canonical:
             episode.show_name = canonical
@@ -113,15 +106,17 @@ class TvRenamr():
             episode.show_name = self.config.get_canonical(episode.show_name)
         log.debug('Show Name: %s' % episode.show_name)
 
+        # loop the libraries until one works
         for lib in libraries:
             try:
-                log.debug('Using %s' % lib[1].__name__)
-                self.library = lib[1](episode.show_name, episode.season, episode.episode)
-                break
-            except XMLSyntaxError:
+                log.debug('Using %s' % lib.__name__)
+                self.library = lib(episode.show_name, episode.season, episode.episode)
+                break # first library worked - nothing to see here
+            except (EmptyEpisodeNameException, EpisodeNotFoundException,
+                    NoNetworkConnectionException, ShowNotFoundException,
+                    XMLEmptyException):
                 if lib == libraries[-1]:
                     raise NoMoreLibrariesException
-                log.debug('Got broken XML from %s. Falling back to next library' % lib[1].__name__)
                 continue
 
         self.title = self.library.title
@@ -273,7 +268,7 @@ class TvRenamr():
         episode = r"(?P<episode>[\d]{2})"
 
         if regex is None:
-            return series + r"\.[Ss]?" + season + r"[XxEe]" + episode + r"\.|-"
+            return series + r"\.[Ss]?" + season + r"[XxEe]?" + episode + r"\.|-"
         if regex.find('%s') is -1 or regex.find('%e') is -1:
             raise IncorrectCustomRegularExpressionSyntaxException(regex)
 
@@ -349,3 +344,4 @@ class TvRenamr():
             return show_name
         log.debug('Moving leading \'The\' to end of: ' + show_name)
         return show_name[4:] + ', The'
+
